module.exports = defineTest({
	description: 'removes an empty try-catch-finally statement'
});
